==> apt-cacher-ng_0.5.1.orig.tar.gz: apt-cacher-ng-0.5.1/include/aclogger.h <==
#ifndef _ACLOGGER_H
#define _ACLOGGER_H

#include "config.h"
#include "meta.h"

#ifdef DEBUG
#include <sstream>
struct t_logger
{
	t_logger(const char *szFuncName); // starts the logger, shifts stack depth
	~t_logger();
	MYSTD::ostringstream & GetFmter();
	void Write(const char *pFile=NULL, unsigned int nLine=0);
private:
	MYSTD::ostringstream m_strm;
	pthread_t m_id;
	unsigned int m_nLevel;
	const char * m_szName;
};
#endif


namespace aclog {

      bool open();
      void close(bool bReopen);
      void transfer(bool bDirIn, uint64_t nCount, const char *szClient, const char *szPath);
      void err(const char *msg, const char *client=NULL);
      void misc(const MYSTD::string & sLine);
      inline void err(const MYSTD::string msg) { err(msg.c_str()); }
      void flush();
      
      void GenerateReport(MYSTD::string &);
      
      class tRowData
      {
      public:
      	uint64_t byteIn, byteOut;
      	unsigned long reqIn, reqOut;
      	time_t from, to;
      	tRowData() : byteIn(0), byteOut(0), reqIn(0), reqOut(0), from(0), to(0) 
      	{};
      	/*
      	tRowData(const tRowData &a) : 
      		byteIn(a.byteIn), byteOut(a.byteOut),
      		reqIn(a.reqIn), reqOut(a.reqOut),
      		from(a.from), to(a.to)
      	{
      	};
      	*/
      private:
    	 // tRowData & operator=(const tRowData &a);
      };

      MYSTD::string GetStatReport();
      
      struct errnoFmter {
    	  errnoFmter();
    	  const char *msg;
      };
}

//#define TIMEFORMAT "%a %d/%m"
#define TIMEFORMAT "%Y-%m-%d %H:%M"


#endif

==> apt-cacher-ng_0.5.14.tar.gz: apt-cacher-ng-0.5.14/include/aclogger.h <==
#ifndef _ACLOGGER_H
#define _ACLOGGER_H

#include "config.h"
#include "meta.h"
#include "acbuf.h"

#ifdef DEBUG

struct t_logger
{
	t_logger(const char *szFuncName); // starts the logger, shifts stack depth
	~t_logger();
	tSS & GetFmter();
	void Write(const char *pFile=NULL, unsigned int nLine=0);
private:
	tSS m_strm;
	pthread_t m_id;
	unsigned int m_nLevel;
	const char * m_szName;
	// don't copy
	t_logger(const t_logger&);
	t_logger operator=(const t_logger&);
};
#endif


namespace aclog
{

      bool open();
      void close(bool bReopen);
      void transfer(char cLogType, uint64_t nCount, const char *szClient, const char *szPath);
      void err(const char *msg, const char *client=NULL);
      void misc(const mstring & sLine, const char cLogType='M');
      inline void err(const mstring msg) { err(msg.c_str()); }
      void flush();
      
      void GenerateReport(mstring &);
      
      class tRowData
      {
      public:
      	uint64_t byteIn, byteOut;
      	unsigned long reqIn, reqOut;
      	time_t from, to;
      	tRowData() : byteIn(0), byteOut(0), reqIn(0), reqOut(0), from(0), to(0) 
      	{};
      	/*
      	tRowData(const tRowData &a) : 
      		byteIn(a.byteIn), byteOut(a.byteOut),
      		reqIn(a.reqIn), reqOut(a.reqOut),
      		from(a.from), to(a.to)
      	{
      	};
      	*/
      private:
    	 // tRowData & operator=(const tRowData &a);
      };

      mstring GetStatReport();
      
      struct errnoFmter : public mstring {
    	  errnoFmter();
      };
}

//#define TIMEFORMAT "%a %d/%m"
#define TIMEFORMAT "%Y-%m-%d %H:%M"


#endif
